==> odps-center-api-1.1.72-20230711.024527-4-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerOrderDetailDfDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * 开发者订单数据接口回传
 *
 * @author qiurenjie
 * @date 2023-03-25 10:07
 */
public class DuibaPartnerOrderDetailDfDTO implements Serializable {

    /**
     * 自增主键
     */
    private Long id;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 订单类型
     */
    private String chargeMode;

    /**
     * 开发者客户id
     */
    private String partnerUserId;

    /**
     * 订单创建时间
     */
    private String orderCreateTime;

    /**
     * 订单完成时间
     */
    private String orderFinishTime;

    /**
     * 兑吧订单号
     */
    private String orderNum;

    /**
     * 开发者订单号
     */
    private String developerBizId;

    /**
     * 商品名称
     */
    private String brief;

    /**
     * 商家编码
     */
    private String merchantCoding;

    /**
     * 消耗积分数
     */
    private Long credits;

    /**
     * 成本
     */
    private String duibaActualPrice;

    /**
     * 收入金额
     */
    private String consumerPayPrice;

    /**
     * 订单状态
     */
    private String orderStatus;

    /**
     * 失败原因
     */
    private String error4admin;

    /**
     * 支付状态
     */
    private String payStatus;

    /**
     * 收货信息
     */
    private String bizParams;

    /**
     * 快递公司
     */
    private String expressName;

    /**
     * 物流编号
     */
    private String expressNum;

    /**
     * 预约信息
     */
    private String yyxx;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getChargeMode() {
        return chargeMode;
    }

    public void setChargeMode(String chargeMode) {
        this.chargeMode = chargeMode;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getOrderCreateTime() {
        return orderCreateTime;
    }

    public void setOrderCreateTime(String orderCreateTime) {
        this.orderCreateTime = orderCreateTime;
    }

    public String getOrderFinishTime() {
        return orderFinishTime;
    }

    public void setOrderFinishTime(String orderFinishTime) {
        this.orderFinishTime = orderFinishTime;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getDeveloperBizId() {
        return developerBizId;
    }

    public void setDeveloperBizId(String developerBizId) {
        this.developerBizId = developerBizId;
    }

    public String getBrief() {
        return brief;
    }

    public void setBrief(String brief) {
        this.brief = brief;
    }

    public String getMerchantCoding() {
        return merchantCoding;
    }

    public void setMerchantCoding(String merchantCoding) {
        this.merchantCoding = merchantCoding;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public String getDuibaActualPrice() {
        return duibaActualPrice;
    }

    public void setDuibaActualPrice(String duibaActualPrice) {
        this.duibaActualPrice = duibaActualPrice;
    }

    public String getConsumerPayPrice() {
        return consumerPayPrice;
    }

    public void setConsumerPayPrice(String consumerPayPrice) {
        this.consumerPayPrice = consumerPayPrice;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getError4admin() {
        return error4admin;
    }

    public void setError4admin(String error4admin) {
        this.error4admin = error4admin;
    }

    public String getPayStatus() {
        return payStatus;
    }

    public void setPayStatus(String payStatus) {
        this.payStatus = payStatus;
    }

    public String getBizParams() {
        return bizParams;
    }

    public void setBizParams(String bizParams) {
        this.bizParams = bizParams;
    }

    public String getExpressName() {
        return expressName;
    }

    public void setExpressName(String expressName) {
        this.expressName = expressName;
    }

    public String getExpressNum() {
        return expressNum;
    }

    public void setExpressNum(String expressNum) {
        this.expressNum = expressNum;
    }

    public String getYyxx() {
        return yyxx;
    }

    public void setYyxx(String yyxx) {
        this.yyxx = yyxx;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> odps-center-api-1.2.1-sources.jar: cn/com/duiba/odps/center/api/dto/hsbc/DuibaPartnerOrderDetailDfDTO.java <==
package cn.com.duiba.odps.center.api.dto.hsbc;

import java.io.Serializable;
import java.util.Date;

/**
 * 开发者订单数据接口回传
 *
 * @author qiurenjie
 * @date 2023-03-25 10:07
 */
public class DuibaPartnerOrderDetailDfDTO implements Serializable {

    /**
     * 自增主键
     */
    private Long id;

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 订单类型
     */
    private String chargeMode;

    /**
     * 开发者客户id
     */
    private String partnerUserId;

    /**
     * 订单创建时间
     */
    private Date orderCreateTime;

    /**
     * 订单完成时间
     */
    private Date orderFinishTime;

    /**
     * 兑吧订单号
     */
    private String orderNum;

    /**
     * 开发者订单号
     */
    private String developerBizId;

    /**
     * 商品名称
     */
    private String brief;

    /**
     * 商家编码
     */
    private String merchantCoding;

    /**
     * 消耗积分数
     */
    private Long credits;

    /**
     * 成本
     */
    private String duibaActualPrice;

    /**
     * 收入金额
     */
    private String consumerPayPrice;

    /**
     * 订单状态
     */
    private String orderStatus;

    /**
     * 失败原因
     */
    private String error4admin;

    /**
     * 支付状态
     */
    private String payStatus;

    /**
     * 收货信息
     */
    private String bizParams;

    /**
     * 快递公司
     */
    private String expressName;

    /**
     * 物流编号
     */
    private String expressNum;

    /**
     * 预约信息
     */
    private String yyxx;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getChargeMode() {
        return chargeMode;
    }

    public void setChargeMode(String chargeMode) {
        this.chargeMode = chargeMode;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Date getOrderCreateTime() {
        return orderCreateTime;
    }

    public void setOrderCreateTime(Date orderCreateTime) {
        this.orderCreateTime = orderCreateTime;
    }

    public Date getOrderFinishTime() {
        return orderFinishTime;
    }

    public void setOrderFinishTime(Date orderFinishTime) {
        this.orderFinishTime = orderFinishTime;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }

    public String getDeveloperBizId() {
        return developerBizId;
    }

    public void setDeveloperBizId(String developerBizId) {
        this.developerBizId = developerBizId;
    }

    public String getBrief() {
        return brief;
    }

    public void setBrief(String brief) {
        this.brief = brief;
    }

    public String getMerchantCoding() {
        return merchantCoding;
    }

    public void setMerchantCoding(String merchantCoding) {
        this.merchantCoding = merchantCoding;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public String getDuibaActualPrice() {
        return duibaActualPrice;
    }

    public void setDuibaActualPrice(String duibaActualPrice) {
        this.duibaActualPrice = duibaActualPrice;
    }

    public String getConsumerPayPrice() {
        return consumerPayPrice;
    }

    public void setConsumerPayPrice(String consumerPayPrice) {
        this.consumerPayPrice = consumerPayPrice;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getError4admin() {
        return error4admin;
    }

    public void setError4admin(String error4admin) {
        this.error4admin = error4admin;
    }

    public String getPayStatus() {
        return payStatus;
    }

    public void setPayStatus(String payStatus) {
        this.payStatus = payStatus;
    }

    public String getBizParams() {
        return bizParams;
    }

    public void setBizParams(String bizParams) {
        this.bizParams = bizParams;
    }

    public String getExpressName() {
        return expressName;
    }

    public void setExpressName(String expressName) {
        this.expressName = expressName;
    }

    public String getExpressNum() {
        return expressNum;
    }

    public void setExpressNum(String expressNum) {
        this.expressNum = expressNum;
    }

    public String getYyxx() {
        return yyxx;
    }

    public void setYyxx(String yyxx) {
        this.yyxx = yyxx;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
